WaveDrawable class

Constructors

WaveDrawable(int N)

Properties

hashCode → int
The hash code for this object.
no setterinherited
L ↔ double
latefinal
maxRadius → double
no setter
maxSpeed → double
no setter
minRadius → double
no setter
minSpeed → double
no setter
N → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

draw(Canvas canvas, Paint paint, Size size) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAmplitude(double value) → void
setAutoScale(bool autoScale) → void
setColors(List<Color>? colors) → void
setMaxRadius(double maxRadius) → void
setMaxSpeed(double maxSpeed) → void
setMinRadius(double minRadius) → void
setScale(double scale) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited